@@ -27,6 +27,8 @@ import {
   setSavedVm,
 } from './actions'
 
+import SelectBox from '../SelectBox'
+
 import { MAX_VM_MEMORY_FACTOR } from '../../constants/index'
 
 function sortedBy (immutableCollection, sortBy) { // TODO: move to helpers
@@ -50,6 +52,11 @@ class VmDialog extends React.Component {
       description: '',
       cpus: 1,
       memory: 1024 * 1024 * 1024,
+      cdrom: {
+        file: {
+          id: '',
+        },
+      },
 
       clusterId: undefined,
       templateId: undefined,
@@ -78,6 +85,7 @@ class VmDialog extends React.Component {
     this.onChangeVmDescription = this.onChangeVmDescription.bind(this)
     this.onChangeVmMemory = this.onChangeVmMemory.bind(this)
     this.onChangeVmCpu = this.onChangeVmCpu.bind(this)
+    this.onChangeCD = this.onChangeCD.bind(this)
   }
 
   componentWillMount () {
@@ -86,7 +94,7 @@ class VmDialog extends React.Component {
 
   componentDidMount () {
     const vm = this.props.vm
-    if (vm) { // "edit" mode
+    if (vm) { // 'edit' mode
       this.setState({
         id: vm.get('id'),
         name: vm.get('name'),
@@ -97,6 +105,11 @@ class VmDialog extends React.Component {
         clusterId: vm.getIn(['cluster', 'id']),
         templateId: vm.getIn(['template', 'id']),
         osId: this.getOsIdFromType(vm.getIn(['os', 'type'])),
+        cdrom: {
+          file: {
+            id: null,
+          },
+        },
       })
     }
     setTimeout(() => this.initDefaults(), 0)
@@ -115,7 +128,7 @@ class VmDialog extends React.Component {
     e.preventDefault()
     this.props.vm
       ? this.props.updateVm(this.composeVm(), actionUniqueId)
-      : this.props.addVm(this.composeVm(), actionUniqueId)
+      : this.props.addVm(this.composeVm(), actionUniqueId, this.props.vms.get('page'))
     this.setState({
       saved: true,
     })
@@ -163,6 +176,11 @@ class VmDialog extends React.Component {
       'cluster': { 'id': this.state.clusterId },
       'memory': this.state.memory,
       'memory_policy': this.getMemoryPolicy(),
+      'cdrom': {
+        'file': {
+          'id': this.state.cdrom.file.id === null ? '' : this.state.cdrom.file.id,
+        },
+      },
       'os': {
         'type': os.get('name'),
       },
@@ -173,6 +191,7 @@ class VmDialog extends React.Component {
           'threads': '1',
         },
       },
+      'status': this.props.vm ? this.props.vm.get('status') : '',
     }
   }
 
@@ -196,6 +215,10 @@ class VmDialog extends React.Component {
     this.onIntegerChanged({ stateProp: 'cpus', value: event.target.value })
   }
 
+  onChangeCD (fileId) {
+    this.setState({ cdrom: { file: { id: fileId } }, isChanged: true })
+  }
+
   onIntegerChanged ({ value, stateProp, factor = 1 }) {
     const intVal = parseInt(value)
     if (!isNaN(intVal)) {
@@ -209,8 +232,8 @@ class VmDialog extends React.Component {
     }
   }
 
-  onChangeOperatingSystem (event) {
-    this.doChangeOsIdTo(event.target.value)
+  onChangeOperatingSystem (osId) {
+    this.doChangeOsIdTo(osId)
   }
 
   doChangeOsIdTo (osId) {
@@ -244,8 +267,7 @@ class VmDialog extends React.Component {
   /**
    * User selected different template.
    */
-  onChangeTemplate (event) {
-    const templateId = event.target.value
+  onChangeTemplate (templateId) {
     this.doChangeTemplateIdTo(templateId)
   }
 
@@ -291,8 +313,7 @@ class VmDialog extends React.Component {
   /**
    * User selected different cluster.
    */
-  onChangeCluster (event) {
-    const clusterId = event.target.value
+  onChangeCluster (clusterId) {
     this.setState({
       clusterId,
     })
@@ -320,6 +341,14 @@ class VmDialog extends React.Component {
     return undefined
   }
 
+  getCDRomFileId () {
+    if (this.state.cdrom.file.id !== null) {
+      return this.state.cdrom.file.id
+    } else {
+      return this.props.vm.get('cdrom') ? this.props.vm.getIn(['cdrom', 'file', 'id']) : ''
+    }
+  }
+
   initDefaults () {
     const { clusters, templates, operatingSystems } = this.props
 
@@ -350,8 +379,19 @@ class VmDialog extends React.Component {
   }
 
   render () {
-    const { icons, vmDialog, clusters, templates, operatingSystems } = this.props
+    const { icons, vmDialog, clusters, templates, operatingSystems, storages } = this.props
     const vm = this.props.vm
+    const isoStorages = storages.get('storages').filter(v => v.get('type') === 'iso')
+
+    let files = { '': { id: '', value: '[Eject]' } }
+
+    isoStorages.toList().forEach(v => {
+      if (v.get('files')) {
+        v.get('files').forEach(item => {
+          files[item['id']] = { id: item['id'], value: item['name'] }
+        })
+      }
+    })
 
     if (this.state.saved && vmDialog.getIn(['vm', 'id'])) {
       return (<Redirect to={`/vm/${vmDialog.getIn(['vm', 'id'])}`} />)
@@ -362,7 +402,6 @@ class VmDialog extends React.Component {
     const sortedClusters = sortedBy(clusters.get('clusters'), 'name')
 
     const filteredTemplates = templates.get('templates')
-      .toList()
       .filter(template => template.get('clusterId') === this.state.clusterId || !template.get('clusterId'))
     const sortedTemplates = sortedBy(filteredTemplates, 'name')
 
@@ -371,6 +410,7 @@ class VmDialog extends React.Component {
     const cluster = this.getCluster()
     const template = this.getTemplate()
     const os = this.getOS()
+    const cdromFileId = this.getCDRomFileId()
 
     const submitText = isEdit ? 'Update VM' : 'Create VM'
 
@@ -428,49 +468,40 @@ class VmDialog extends React.Component {
               <dt>
                 <FieldHelp content='Group of hosts the virtual machine can be running on.' text='Cluster' />
               </dt>
-              <dd>
-                <select
-                  className='combobox form-control'
+              <dd className={style['field-overflow-visible']}>
+                <SelectBox
                   onChange={this.onChangeCluster}
-                  value={cluster ? cluster.get('id') : ''} >
-                  {sortedClusters.toList().map(item => (
-                    <option value={item.get('id')} key={item.get('id')}>
-                      {item.get('name')}
-                    </option>
-                  ))}
-                </select>
+                  selected={cluster ? cluster.get('id') : ''}
+                  items={sortedClusters.map(item => (
+                    { id: item.get('id'), value: item.get('name') }
+                  )).toJS()}
+                  />
               </dd>
 
               <dt>
                 <FieldHelp content='Contains the configuration and disks which will be used to create this virtual machine. Please customize as needed.' text='Template' />
               </dt>
-              <dd>
-                <select
-                  className='combobox form-control'
+              <dd className={style['field-overflow-visible']}>
+                <SelectBox
                   onChange={this.onChangeTemplate}
-                  value={template ? template.get('id') : ''} >
-                  {sortedTemplates.toList().map(item => (
-                    <option value={item.get('id')} key={item.get('id')}>
-                      {templateNameRenderer(item)}
-                    </option>
-                  ))}
-                </select>
+                  selected={template ? template.get('id') : ''}
+                  items={sortedTemplates.map(item => (
+                    { id: item.get('id'), value: templateNameRenderer(item) }
+                  )).toJS()}
+                  />
               </dd>
 
               <dt>
                 <FieldHelp content='Operating system installed on the virtual machine.' text='Operating System' />
               </dt>
-              <dd>
-                <select
-                  className='combobox form-control'
+              <dd className={style['field-overflow-visible']}>
+                <SelectBox
                   onChange={this.onChangeOperatingSystem}
-                  value={os ? os.get('id') : ''} >
-                  {sortedOSs.toList().map(item => (
-                    <option value={item.get('id')} key={item.get('id')}>
-                      {item.get('description')}
-                    </option>
-                  ))}
-                </select>
+                  selected={os ? os.get('id') : ''}
+                  items={sortedOSs.map(item => (
+                    { id: item.get('id'), value: item.get('description') }
+                  )).toJS()}
+                  />
               </dd>
 
               <dt>
@@ -506,6 +537,18 @@ class VmDialog extends React.Component {
                   min={1}
                   step={1} />
               </dd>
+              <dt>
+                <span className='pficon pficon-storage-domain' />
+                &nbsp;
+                <FieldHelp content='Change CD.' text='CDRom' />
+              </dt>
+              <dd className={style['field-overflow-visible']}>
+                <SelectBox
+                  onChange={this.onChangeCD}
+                  selected={cdromFileId}
+                  items={files}
+                  />
+              </dd>
 
             </dl>
           </div>
@@ -531,6 +574,7 @@ VmDialog.propTypes = {
   vmDialog: PropTypes.object.isRequired,
   icons: PropTypes.object.isRequired,
   vms: PropTypes.object.isRequired,
+  storages: PropTypes.object.isRequired,
 
   onCloseDialog: PropTypes.func.isRequired,
   addVm: PropTypes.func.isRequired,
@@ -547,10 +591,11 @@ export default connect(
     vmDialog: state.VmDialog,
     icons: state.icons,
     vms: state.vms,
+    storages: state.storages,
   }),
   (dispatch) => ({
     onCloseDialog: () => dispatch(closeDialog({ force: false })),
-    addVm: (vm, actionUniqueId) => dispatch(createVm(vm, actionUniqueId)),
+    addVm: (vm, actionUniqueId, page) => dispatch(createVm(vm, actionUniqueId, page)),
     updateVm: (vm, actionUniqueId) => dispatch(editVm(vm, actionUniqueId)),
     onInit: () => dispatch(setSavedVm({ vm: null })),
   })
