@@ -7,10 +7,12 @@ import { Exception } from './exceptions'
 import Selectors from './selectors'
 import AppConfiguration from './config'
 
-type VmIdType = { vmId: string };
-type PoolIdType = { poolId: string };
-type InputRequestType = { url: string, input: string, contentType?: string };
-type VmType = { vm: Object };
+type VmIdType = { vmId: string }
+type PoolIdType = { poolId: string }
+type InputRequestType = { url: string, input: string, contentType?: string }
+type VmType = { vm: Object }
+
+const zeroUUID: string = '00000000-0000-0000-0000-000000000000'
 
 let OvirtApi = {}
 OvirtApi = {
@@ -110,9 +112,11 @@ OvirtApi = {
       description: vm['description'],
       id: vm['id'],
       status: vm['status'] ? vm['status'].toLowerCase() : undefined,
+      statusDetail: vm['status_detail'],
       type: vm['type'],
       nextRunExists: vm['next_run_configuration_exists'] === 'true',
       lastMessage: '',
+      hostId: vm['host'] ? vm['host'].id : undefined,
 
       // TODO: improve time conversion
       startTime: vm['start_time'] ? (new Date(vm['start_time'])).toUTCString() : undefined,
@@ -220,6 +224,14 @@ OvirtApi = {
     }
   },
 
+  internalCDRomToOvirt ({ cdrom }: { cdrom: Object }): Object {
+    return {
+      file: {
+        id: cdrom.file.id,
+      },
+    }
+  },
+
   /**
    *
    * @param attachment - single entry from vms/[VM_ID]/diskattachments
@@ -275,6 +287,7 @@ OvirtApi = {
 
     }
   },
+
   clusterToInternal ({ cluster }: { cluster: Object }): Object {
     return {
       id: cluster.id,
@@ -286,11 +299,44 @@ OvirtApi = {
     }
   },
 
+  hostToInternal ({ host }: { host: Object }): Object {
+    return {
+      id: host.id,
+      name: host.name,
+
+      address: host.address,
+      clusterId: host.cluster && host.cluster.id,
+    }
+  },
+
   OSToInternal ({ os }: { os: Object }): Object {
     return {
       id: os.id,
       name: os.name,
       description: os.description,
+      icons: {
+        small: {
+          id: os['small_icon'] ? os.small_icon['id'] : undefined,
+        },
+        large: {
+          id: os['large_icon'] ? os.large_icon['id'] : undefined,
+        },
+      },
+    }
+  },
+
+  storageToInternal ({ storage }: { storage: Object }): Object {
+    return {
+      id: storage.id,
+      name: storage.name,
+      type: storage.type,
+    }
+  },
+
+  fileToInternal ({ file }: { file: Object }): Object {
+    return {
+      id: file.id,
+      name: file.name,
     }
   },
 
@@ -311,6 +357,15 @@ OvirtApi = {
     }
   },
 
+  CDRomToInternal ({ cdrom }: { cdrom: Object }): Object {
+    return {
+      id: cdrom.id,
+      file: {
+        id: cdrom.file ? cdrom.file.id : '',
+      },
+    }
+  },
+
   consolesToInternal ({ consoles }: { consoles: Object }): Array<Object> {
     return consoles['graphics_console'].map((c: Object): Object => {
       return {
@@ -347,9 +402,14 @@ OvirtApi = {
     const url = `${AppConfiguration.applicationContext}/api/vms/${vmId}`
     return OvirtApi._httpGet({ url })
   },
-  getAllVms (): Promise<Object> {
-    OvirtApi._assertLogin({ methodName: 'getAllVms' })
-    const url = `${AppConfiguration.applicationContext}/api/vms`
+  getVmsByPage ({ page }: { page: number }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getVmsByPage' })
+    const url = `${AppConfiguration.applicationContext}/api/vms/;max=${AppConfiguration.pageLimit}?search=SORTBY NAME ASC page ${page}`
+    return OvirtApi._httpGet({ url })
+  },
+  getVmsByCount ({ count }: { count: number }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getVmsByCount' })
+    const url = `${AppConfiguration.applicationContext}/api/vms/;max=${count}?search=SORTBY NAME ASC`
     return OvirtApi._httpGet({ url })
   },
   shutdown ({ vmId, force }: { vmId: string, force: boolean }): Promise<Object> {
@@ -387,6 +447,11 @@ OvirtApi = {
     const url = `${AppConfiguration.applicationContext}/api/clusters`
     return OvirtApi._httpGet({ url })
   },
+  getAllHosts (): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getAllHosts' })
+    const url = `${AppConfiguration.applicationContext}/api/hosts`
+    return OvirtApi._httpGet({ url })
+  },
   getAllOperatingSystems (): Promise<Object> {
     OvirtApi._assertLogin({ methodName: 'getAllOperatingSystems' })
     const url = `${AppConfiguration.applicationContext}/api/operatingsystems`
@@ -405,7 +470,7 @@ OvirtApi = {
     OvirtApi._assertLogin({ methodName: 'editVm' })
     return OvirtApi._httpPut({
       url: `${AppConfiguration.applicationContext}/api/vms/${vm.id}`,
-      input: JSON.stringify(vm),
+      input: JSON.stringify(OvirtApi.internalVmToOvirt({ vm })),
     })
   },
   start ({ vmId }: VmIdType): Promise<Object> {
@@ -463,9 +528,15 @@ OvirtApi = {
     return OvirtApi._httpGet({ url: `${AppConfiguration.applicationContext}/api/permissions`, custHeaders: { Filter: false } })
   },
 
-  getAllPools (): Promise<Object> {
-    OvirtApi._assertLogin({ methodName: 'getAllPools' })
-    const url = `${AppConfiguration.applicationContext}/api/vmpools`
+  getPoolsByPage ({ page }: { page: number }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getPoolsByPage' })
+    const url = `${AppConfiguration.applicationContext}/api/vmpools/;max=${AppConfiguration.pageLimit}?search=SORTBY NAME ASC page ${page}`
+    return OvirtApi._httpGet({ url })
+  },
+
+  getPoolsByCount ({ count }: { count: number }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getPoolsByCount' })
+    const url = `${AppConfiguration.applicationContext}/api/vmpools/;max=${count}`
     return OvirtApi._httpGet({ url })
   },
 
@@ -478,6 +549,38 @@ OvirtApi = {
     OvirtApi._assertLogin({ methodName: 'sessions' })
     return OvirtApi._httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/sessions` })
   },
+  getStorages (): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getStorages' })
+    return OvirtApi._httpGet({ url: `${AppConfiguration.applicationContext}/api/storagedomains` })
+  },
+  getStorageFiles ({ storageId }: { storageId: string }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getStorageFiles' })
+    return OvirtApi._httpGet({ url: `${AppConfiguration.applicationContext}/api/storagedomains/${storageId}/files` })
+  },
+
+  getCDRom ({ vmId, running }: { vmId: string, running: boolean }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getCDRom' })
+    return OvirtApi._httpGet({ url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/cdroms/${zeroUUID}?current=${running ? 'true' : 'false'}` })
+  },
+
+  changeCD ({ cdrom, vmId, running }: { cdrom: Object, vmId: string, running: boolean }): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'changeCD' })
+    const input = JSON.stringify(OvirtApi.internalCDRomToOvirt({ cdrom }))
+    logDebug(`OvirtApi.changeCD(): ${input}`)
+    return OvirtApi._httpPut({
+      url: `${AppConfiguration.applicationContext}/api/vms/${vmId}/cdroms/${zeroUUID}?current=${running ? 'true' : 'false'}`,
+      input,
+    })
+  },
+  getUSBFilter (): Promise<Object> {
+    OvirtApi._assertLogin({ methodName: 'getUSBFilter' })
+    return OvirtApi._httpGet({
+      url: `${AppConfiguration.applicationContext}/services/files/usbfilter.txt`,
+      custHeaders: {
+        'Accept': 'text/plain',
+      },
+    })
+  },
 }
 
 const Api = OvirtApi
