@@ -13,7 +13,9 @@ const initialState = Immutable.fromJS({
     passed: undefined,
   },
   filter: true,
+  isFilterChecked: false,
   administrator: false,
+  usbFilter: null,
 })
 
 const config = actionReducer(initialState, {
@@ -30,7 +32,9 @@ const config = actionReducer(initialState, {
     return state.merge({ oVirtApiVersion: oVirtApiVersion })
   },
   SET_USER_FILTER_PERMISSION (state, { payload: { filter } }) {
-    return state.set('filter', filter)
+    return state
+      .set('filter', filter)
+      .set('isFilterChecked', true)
   },
   SET_ADMINISTATOR (state, { payload: { administrator } }) {
     return state.set('administrator', administrator)
@@ -42,6 +46,9 @@ const config = actionReducer(initialState, {
   SET_DOMAIN (state, { payload: { domain } }) {
     return state.set('domain', domain)
   },
+  SET_USB_FILTER (state, { payload: { usbFilter } }) {
+    return state.set('usbFilter', usbFilter)
+  },
 })
 
 export default config
